@@ -210,6 +210,8 @@ test_graph_learner = function(task, resampling,
     filter = mlr3filters::flt("importance", learner = lrn)
   )
 
+  # browser()
+
   # Create process (new learner) for filtering the task
   grph = mlr3pipelines::Graph$new()$add_pipeop(po_filter)$add_pipeop(po_lrn)$add_edge("importance", learner) # nolint
   glrn = mlr3pipelines::GraphLearner$new(grph)
@@ -242,127 +244,3 @@ test_graph_learner = function(task, resampling,
 #   testthat::skip_if_not_installed("vdiffr")
 #   vdiffr::expect_doppelganger(title = title, fig = fig, path = path, ...)
 # }
-
-# mlr3spatial ------------------------------------------------------------------
-# FIXME: remove when mlr3spatial > 0.1.2 is on CRAN
-
-#' @title Generate Raster Stack
-#'
-#' @description
-#' Generates a raster stack.
-#'
-#' @param layers (List of [numeric_layer()] and [factor_layer()])\cr
-#'   List of layers.
-#' @param layer_size (`numeric(1)`)\cr
-#'   Size of a single layer in megabytes.
-#' @param dimension (`integer(1)`)\cr
-#'   Dimension of the squared layers.
-#' @param multi_layer_file (`logical(1)`)\cr
-#'   If `TRUE`, raster is written to disk as a single multi-layer file.
-#'   Overwrites `ìn_memory` argument of `numeric_layer()` and `factor_layer()`.
-#'
-#' `layer_size` and `dimension` are mutually exclusive.
-#'
-#' @return [terra::SpatRaster]
-#'
-#' @keywords internal
-generate_stack = function(layers, layer_size = NULL, dimension = NULL,
-  multi_layer_file = FALSE) {
-  if (!xor(is.null(layer_size), is.null(dimension))) {
-    stop("Either `layer_size` or `dimension` must be provided")
-  }
-  assert_list(layers)
-  assert_int(layer_size, null.ok = TRUE)
-  assert_int(dimension, null.ok = TRUE)
-  assert_flag(multi_layer_file)
-  dimension = dimension %??% floor(sqrt(layer_size * 1e+06 / 8))
-  ids = map_chr(layers, "id")
-  assert_character(ids, unique = TRUE)
-
-  layers = map(layers, function(layer) {
-    if (layer$type == "numeric") {
-      data = matrix(c(
-        stats::rnorm(floor(dimension^2 / 2), 0, 1),
-        stats::rnorm(ceiling(dimension^2 / 2), 1, 1)
-      ), nrow = dimension)
-      ras = terra::rast(data)
-      if (!layer$in_memory && !multi_layer_file) {
-        filename = tempfile(fileext = ".tif")
-        terra::writeRaster(ras, filename)
-        ras = terra::rast(filename)
-      }
-      ras
-    } else if (layer$type == "factor") {
-      data = matrix(rep(seq_along(layer$levels),
-        each = floor(dimension^2 / length(layer$levels)),
-        length.out = dimension^2
-      ), nrow = dimension)
-      ras = terra::rast(data)
-
-      ras = terra::categories(ras,
-        layer = 1,
-        data.table(ID = seq_along(layer$levels), category = layer$levels)
-      )
-      if (!layer$in_memory && !multi_layer_file) {
-        filename = tempfile(fileext = ".tif")
-        terra::writeRaster(ras, filename)
-        ras = terra::rast(filename)
-      }
-      ras
-    }
-  })
-
-  stack = terra::rast(layers)
-  terra::crs(stack) = "EPSG:4326"
-  stack = set_names(stack, ids)
-  if (multi_layer_file) {
-    stack = terra::writeRaster(stack,
-      filename = tempfile(fileext = ".tif")
-    )
-  }
-
-  stack
-}
-
-#' @title Numeric Layer Generator
-#'
-#' @description
-#' Generates a numeric layer when passed to [generate_stack()].
-#'
-#' @param id (`character(1)`)\cr
-#'   Layer id.
-#' @param in_memory (`logical(1)`)\cr
-#'   If `FALSE` (default), layer is written to disk.
-#'
-#' @return Named `list()`
-#'
-#' @keywords internal
-numeric_layer = function(id, in_memory = FALSE) {
-  assert_string(id)
-  assert_flag(in_memory)
-
-  list(id = id, type = "numeric", in_memory = in_memory)
-}
-
-#' @title Factor Layer Generator
-#'
-#' @description
-#' Generates a factor layer when passed to [generate_stack()].
-#'
-#' @param id (`character(1)`)\cr
-#'   Layer id.
-#' @param levels (`character()`)\cr
-#'   Factor levels.
-#' @param in_memory (`logical(1)`)\cr
-#'   If `FALSE` (default), layer is written to disk.
-#'
-#' @return Named `list()`
-#'
-#' @keywords internal
-factor_layer = function(id, levels, in_memory = FALSE) {
-  assert_string(id)
-  assert_character(levels)
-  assert_flag(in_memory)
-
-  list(id = id, type = "factor", levels = levels, in_memory = in_memory)
-}
