@@ -1,7 +1,8 @@
 test_that("spcv methods work in a Graph Learner", {
-  skip("until mlr3filters >= 0.5.1 in on CRAN - including as_task assertion fix")
   skip_if_not_installed("mlr3pipelines")
   skip_if_not_installed("blockCV")
+  skip_if_not_installed("raster")
+  skip_on_cran() # "Cannot reproduce winbuilder failure"
 
   # - spcv_buffer is missing due to runtime reasons
   # - spcv_block is missing due to runtime reasons
